from setuptools import setup

setup(name='bgdist',
      version='1.0',
      description='A package for Gaussian & Binomial distributions',
      packages=['bgdist'],
      author='Tapajyoti Deb',
      author_email='tapajyotideb@gmail.com',
     zip_safe=False)
